This is unreleased documentation for Yew Next version.
For up-to-date documentation, see the latest version on docs.rs.

AllPropsFor

Trait AllPropsFor 

pub trait AllPropsFor<Builder, How> { }
Trait to specify the requirement for Self to be a valid token signaling all props have been provided to the builder.

Implementors

Source

impl<Token, Builder: Buildable<Token>, How> AllPropsFor<Builder, How> for Token
where Builder::WrappedToken: HasAllProps<Builder::Output, How>,